from random_word.random_word import RandomWords
from random_word.services.apininjas import ApiNinjas
from random_word.services.wordnik import Wordnik

__all__ = ["Wordnik", "ApiNinjas", "RandomWords"]
__name__ = "Random Word"
__author__ = "Vaibhav Singh <hi@vaibhavsingh97.com>"
__version__ = "1.0.11"
